pub struct ResourceRegistry { /* private fields */ }Expand description
Registry for resource types.
The registry maps type URLs to resource metadata and provides utilities for working with different resource types.
Implementations
Sourceimpl ResourceRegistry
impl ResourceRegistry
Sourcepub fn with_envoy_types() -> Self
pub fn with_envoy_types() -> Self
Create a registry pre-populated with standard Envoy types.
Sourcepub fn register(&mut self, info: ResourceTypeInfo)
pub fn register(&mut self, info: ResourceTypeInfo)
Register a new resource type.
Sourcepub fn get(&self, type_url: &str) -> Option<&ResourceTypeInfo>
pub fn get(&self, type_url: &str) -> Option<&ResourceTypeInfo>
Get information about a resource type by type URL.
Sourcepub fn iter(&self) -> impl Iterator<Item = (&String, &ResourceTypeInfo)>
pub fn iter(&self) -> impl Iterator<Item = (&String, &ResourceTypeInfo)>
Iterate over all registered types.